@@ -20,6 +20,7 @@ class ModuleInfo(base_info.BaseInfo):
         self.class_ignored = []
         self.free_function_info = []
         self.variable_info = []
+        self.variable_ignored = []
         self.enum_info = []
         self.namespace = []
         self.struct_repr = []
@@ -27,6 +28,8 @@ class ModuleInfo(base_info.BaseInfo):
         self.use_all_classes = False
         self.use_all_free_functions = False
         self.use_all_enums = False
+        self.template_function_mapping = {}
+        self.function_mapping = {}
 
         if type_info_dict is not None:
             for key in type_info_dict:
